@@ -1,4 +1,5 @@
 import enum
+import os
 import uuid
 
 from cairosvg import svg2png
@@ -155,6 +156,10 @@ class MouthType(AvatarEnum):
     VOMIT = 120
 
 
+class NoseType(AvatarEnum):
+    DEFAULT = 10
+
+
 class EyesType(AvatarEnum):
     DEFAULT = 10
     CLOSE = 20
@@ -209,6 +214,7 @@ class PyAvataaar(object):
             hat_color: ClotheColor = ClotheColor.BLACK,
             mouth_type: MouthType = MouthType.SMILE,
             eye_type: EyesType = EyesType.DEFAULT,
+            nose_type: NoseType = NoseType.DEFAULT,
             eyebrow_type: EyebrowType = EyebrowType.DEFAULT,
             accessories_type: AccessoriesType = AccessoriesType.DEFAULT,
             clothe_type: ClotheType = ClotheType.GRAPHIC_SHIRT,
@@ -225,6 +231,7 @@ class PyAvataaar(object):
         self.hat_color = hat_color
         self.mouth_type = mouth_type
         self.eye_type = eye_type
+        self.nose_type = nose_type
         self.eyebrow_type = eyebrow_type
         self.accessories_type = accessories_type
         self.clothe_type = clothe_type
@@ -233,12 +240,24 @@ class PyAvataaar(object):
 
     @staticmethod
     def __unique_id(prefix: str = None) -> str:
-        sub_values = [prefix, str(uuid.uuid4())]
+        sub_values = ['py-avataaars', prefix, str(uuid.uuid4())]
         return "-".join(filter(None, sub_values))
 
     @staticmethod
     def __template_path(path: str, enum_type: AvatarEnum) -> str:
-        return f"{path}{enum_type.name.lower()}.svg"
+        return os.path.join(path, f"{enum_type.name.lower()}.svg")
+
+    @staticmethod
+    def __template_name(context):
+        template_name = getattr(context, '_TemplateReference__context', None) if context else None
+        if template_name:
+            name = template_name.name
+        else:
+            name = str(uuid.uuid4())
+        name = name.replace('.svg', '')
+        name = name.replace('/', '-')
+        name = name.replace('_', '-')
+        return f'py-avataaars-{name}'
 
     def __render_svg(self):
         env = Environment(
@@ -248,6 +267,7 @@ class PyAvataaar(object):
         rendered_template = template.render(
             unique_id=self.__unique_id,
             template_path=self.__template_path,
+            template_name=self.__template_name,
             style=self.style,
             skin_color=self.skin_color,
             hair_color=self.hair_color,
@@ -255,6 +275,7 @@ class PyAvataaar(object):
             hat_color=self.hat_color,
             mouth_type=self.mouth_type,
             eye_type=self.eye_type,
+            nose_type=self.nose_type,
             eyebrow_type=self.eyebrow_type,
             accessories_type=self.accessories_type,
             facial_hair_type=self.facial_hair_type,
@@ -266,7 +287,7 @@ class PyAvataaar(object):
         return rendered_template
 
     def render_png_file(self, output_file: str):
-        svg2png(bytestring=self.__render_svg().encode(), write_to=output_file)
+        svg2png(self.__render_svg(), write_to=output_file)
 
     def render_svg_file(self, output_file: str):
         with open(output_file, 'w') as file:
